package com.fs.store.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreVisitMapper;
import com.fs.store.domain.FsStoreVisit;
import com.fs.store.service.IFsStoreVisitService;

/**
 * 产品浏览分析Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreVisitServiceImpl implements IFsStoreVisitService 
{
    @Autowired
    private FsStoreVisitMapper fsStoreVisitMapper;

    /**
     * 查询产品浏览分析
     * 
     * @param id 产品浏览分析ID
     * @return 产品浏览分析
     */
    @Override
    public FsStoreVisit selectFsStoreVisitById(Long id)
    {
        return fsStoreVisitMapper.selectFsStoreVisitById(id);
    }

    /**
     * 查询产品浏览分析列表
     * 
     * @param fsStoreVisit 产品浏览分析
     * @return 产品浏览分析
     */
    @Override
    public List<FsStoreVisit> selectFsStoreVisitList(FsStoreVisit fsStoreVisit)
    {
        return fsStoreVisitMapper.selectFsStoreVisitList(fsStoreVisit);
    }

    /**
     * 新增产品浏览分析
     * 
     * @param fsStoreVisit 产品浏览分析
     * @return 结果
     */
    @Override
    public int insertFsStoreVisit(FsStoreVisit fsStoreVisit)
    {
        return fsStoreVisitMapper.insertFsStoreVisit(fsStoreVisit);
    }

    /**
     * 修改产品浏览分析
     * 
     * @param fsStoreVisit 产品浏览分析
     * @return 结果
     */
    @Override
    public int updateFsStoreVisit(FsStoreVisit fsStoreVisit)
    {
        return fsStoreVisitMapper.updateFsStoreVisit(fsStoreVisit);
    }

    /**
     * 批量删除产品浏览分析
     * 
     * @param ids 需要删除的产品浏览分析ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreVisitByIds(Long[] ids)
    {
        return fsStoreVisitMapper.deleteFsStoreVisitByIds(ids);
    }

    /**
     * 删除产品浏览分析信息
     * 
     * @param id 产品浏览分析ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreVisitById(Long id)
    {
        return fsStoreVisitMapper.deleteFsStoreVisitById(id);
    }
}
